==> cintap-ui-0.1.17.tgz: package/src/lib/models/BaseModel.js <==
import axios from 'axios';
// import { Helpers } from '~/cintap-ui/dist';
export default class BaseModel {
  constructor(props) {
    Object.keys(props).forEach((field_name) => {
      this[field_name] = props[field_name];
    })
  }

  static setNamespace = (namespace) => {
    BaseModel.namespace = namespace;
  }

  static setApiHost = (apiHost) => {
    BaseModel.apiHost = apiHost;
  }

  static signedHeaders = (accessToken) => {
    return {
      headers: {
        Authorization: `Bearer ${accessToken}`
      }
    }
  }

  static getLocalStorageKey = (key) => {
    return `${BaseModel.namespace}${key}`;
  }

  static getApiUrl = (path, version) => {
    let apiUrl = path;
    if(version === false) {
      if(BaseModel.apiHost.indexOf('/v1') !== -1) {
        apiUrl = `${BaseModel.apiHost.replace('/v1', '')}${path}`;
      } else {
        apiUrl = `${BaseModel.apiHost}${path}`;
      }
    } else {
      if(version === undefined || version === null) {
        if(BaseModel.apiHost.indexOf('/v1') !== -1) {
          apiUrl = `${BaseModel.apiHost}${path}`;
        } else {
          apiUrl = `${BaseModel.apiHost}/v1${path}`;
        }
      } else {
        if(version === '') {
          apiUrl = `${BaseModel.apiHost}${path}`;
        } else {
          apiUrl = `${BaseModel.apiHost}/${version}${path}`;
        }
      }
    }
    return apiUrl;
  }

  static signedGet = (api_path, data, accessToken, version) => {
    return axios.get(this.getApiUrl(api_path, version), BaseModel.signedHeaders(accessToken));
  }

  static signedPost = (api_path, data, accessToken, version) => {
    return axios.post(this.getApiUrl(api_path, version), data, BaseModel.signedHeaders(accessToken));
  }


  static signedPut = (api_path, data, accessToken, version) => {
    return axios.put(this.getApiUrl(api_path, version), data, BaseModel.signedHeaders(accessToken));
  }

  static unsignedGet = (api_path, data, version) => {
    return axios.get(this.getApiUrl(api_path, version), {
      headers: {},
      params: (data || {})
    });
  }

  static unsignedPost = (api_path, data, version) => {
    return axios.post(this.getApiUrl(api_path, version), (
      data || {}
    ))
  }

  // static signedGet = (api_path, data) => {
  //   return axios.get(this.getApiUrl(api_path), {
  //     headers: Helpers.signedHeaders
  //   });
  // }

  // static unsignedPost = (api_path, data) => {
  //   return axios.post(this.getApiUrl(api_path), (data || {}), { headers: Helpers.unsignedHeaders });
  // }

  // static signedPost = (api_path, data, headers) => {
  //   if(!headers){
  //     headers = {}
  //   }
  //   Object.keys(Helpers.signedHeaders).forEach((key) => {
  //     headers[key] = Helpers.signedHeaders[key];
  //   })
  //   return axios.post(this.getApiUrl(api_path), (data || {}), { headers: headers });
  // }

  // static signedPut = (api_path, data, headers) => {
  //   if(!headers){
  //     headers = {}
  //   }
  //   Object.keys(Helpers.signedHeaders).forEach((key) => {
  //     headers[key] = Helpers.signedHeaders[key];
  //   })
  //   return axios.put(this.getApiUrl(api_path), (data || {}), { headers: headers });
  // }
}

==> cintap-ui-0.1.26.tgz: package/src/lib/models/BaseModel.js <==
import axios from 'axios';
// import { Helpers } from '~/cintap-ui/dist';
export default class BaseModel {
  constructor(props) {
    Object.keys(props).forEach((field_name) => {
      this[field_name] = props[field_name];
    })
  }

  static setNamespace = (namespace) => {
    BaseModel.namespace = namespace;
  }

  static setApiHost = (apiHost) => {
    BaseModel.apiHost = apiHost;
  }

  static signedHeaders = (accessToken) => {
    return {
      headers: {
        Authorization: `Bearer ${accessToken}`
      }
    }
  }

  static getLocalStorageKey = (key) => {
    return `${BaseModel.namespace}${key}`;
  }

  static getApiUrl = (path, version) => {
    let apiUrl = path;
    apiUrl = `${BaseModel.apiHost}${path}`;
    if(version === false) {
      if (apiUrl.indexOf("/v1") !== -1) {
        apiUrl = apiUrl.replace("/v1", "");
      }
    } else if(version === undefined || version  === null) {
      if (apiUrl.indexOf("/v1") === -1) {
        apiUrl = `${BaseModel.apiHost}/v1${path}`
      }
    } else {
      if(apiUrl.indexOf(`/${version}`) === -1) {
        apiUrl = `${BaseModel.apiHost}/${version}${path}`
      }
    }
    return apiUrl;
  }

  static signedGet = (api_path, data, accessToken, version) => {
    return axios.get(this.getApiUrl(api_path, version), BaseModel.signedHeaders(accessToken));
  }

  static signedPost = (api_path, data, accessToken, version) => {
    return axios.post(this.getApiUrl(api_path, version), data, BaseModel.signedHeaders(accessToken));
  }


  static signedPut = (api_path, data, accessToken, version) => {
    return axios.put(this.getApiUrl(api_path, version), data, BaseModel.signedHeaders(accessToken));
  }

  static unsignedGet = (api_path, data, version) => {
    return axios.get(this.getApiUrl(api_path, version), {
      headers: {},
      params: (data || {})
    });
  }

  static unsignedPost = (api_path, data, version) => {
    return axios.post(this.getApiUrl(api_path, version), (
      data || {}
    ))
  }

  // static signedGet = (api_path, data) => {
  //   return axios.get(this.getApiUrl(api_path), {
  //     headers: Helpers.signedHeaders
  //   });
  // }

  // static unsignedPost = (api_path, data) => {
  //   return axios.post(this.getApiUrl(api_path), (data || {}), { headers: Helpers.unsignedHeaders });
  // }

  // static signedPost = (api_path, data, headers) => {
  //   if(!headers){
  //     headers = {}
  //   }
  //   Object.keys(Helpers.signedHeaders).forEach((key) => {
  //     headers[key] = Helpers.signedHeaders[key];
  //   })
  //   return axios.post(this.getApiUrl(api_path), (data || {}), { headers: headers });
  // }

  // static signedPut = (api_path, data, headers) => {
  //   if(!headers){
  //     headers = {}
  //   }
  //   Object.keys(Helpers.signedHeaders).forEach((key) => {
  //     headers[key] = Helpers.signedHeaders[key];
  //   })
  //   return axios.put(this.getApiUrl(api_path), (data || {}), { headers: headers });
  // }
}
